diff --git a/htdocs/adherents/class/adherent.class.php b/htdocs/adherents/class/adherent.class.php
index 0f2b92622c0..e97a09559af 100644
--- a/htdocs/adherents/class/adherent.class.php
+++ b/htdocs/adherents/class/adherent.class.php
@@ -1493,19 +1493,17 @@ class Adherent extends CommonObject
/**
- * Return civility label of a contact
+ * Return civility label of a member
*
- * @param int $nohtmlentities 0=Encode with htmlentities for HTML output, 1=No htmlentities for memory translation
- * @return string Name translated of civility
+ * @return string Translated name of civility
*/
- function getCivilityLabel($nohtmlentities=0)
+ function getCivilityLabel()
{
global $langs;
$langs->load("dict");
$code=$this->civilite_id;
- if ($nohtmlentities) return $langs->transnoentities("Civility".$code)!="Civility".$code ? $langs->transnoentities("Civility".$code) : $code;
- else return $langs->trans("Civility".$code)!="Civility".$code ? $langs->trans("Civility".$code) : $code;
+ return $langs->getLabelFromKey($this->db, "Civility".$code, "c_civilite", "code", "civilite", $code);
}
/**
diff --git a/htdocs/adherents/fiche.php b/htdocs/adherents/fiche.php
index 05833bbce10..8c714ab7c67 100644
--- a/htdocs/adherents/fiche.php
+++ b/htdocs/adherents/fiche.php
@@ -246,9 +246,22 @@ if ($action == 'update' && ! $_POST["cancel"] && $user->rights->adherent->creer)
{
$birthdate=dol_mktime(12, 0, 0, $_POST["birthmonth"], $_POST["birthday"], $_POST["birthyear"]);
}
+ $lastname=$_POST["lastname"];
+ $firstname=$_POST["firstname"];
+ $morphy=$morphy=$_POST["morphy"];;
+ if ($morphy != 'mor' && empty($lastname)) {
+ $error++;
+ $langs->load("errors");
+ $errmsg .= $langs->trans("ErrorFieldRequired",$langs->transnoentities("Lastname"))."
\n";
+ }
+ if ($morphy != 'mor' && (!isset($firstname) || $firstname=='')) {
+ $error++;
+ $langs->load("errors");
+ $errmsg .= $langs->trans("ErrorFieldRequired",$langs->transnoentities("Firstname"))."
\n";
+ }
// Create new object
- if ($result > 0)
+ if ($result > 0 && ! $error)
{
$object->oldcopy=dol_clone($object);
@@ -389,6 +402,10 @@ if ($action == 'update' && ! $_POST["cancel"] && $user->rights->adherent->creer)
$action='';
}
}
+ else
+ {
+ $action='edit';
+ }
}
if ($action == 'add' && $user->rights->adherent->creer)
@@ -489,7 +506,7 @@ if ($action == 'add' && $user->rights->adherent->creer)
$errmsg .= $langs->trans("ErrorFieldRequired",$langs->transnoentities("Password"))."
\n";
}
}
- if (empty($lastname)) {
+ if ($morphy != 'mor' && empty($lastname)) {
$error++;
$langs->load("errors");
$errmsg .= $langs->trans("ErrorFieldRequired",$langs->transnoentities("Lastname"))."
\n";
diff --git a/htdocs/comm/propal.php b/htdocs/comm/propal.php
index 09bc17792c0..1ad89847ea8 100644
--- a/htdocs/comm/propal.php
+++ b/htdocs/comm/propal.php
@@ -1858,7 +1858,7 @@ else
// Convert date into timestamp format
if (in_array($extrafields->attribute_type[$key],array('date','datetime')))
{
- $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$object->array_options['options_'.$key];
+ $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$db->jdate($object->array_options['options_'.$key]);
}
if ($action == 'edit_extras' && $user->rights->propal->creer)
diff --git a/htdocs/commande/fiche.php b/htdocs/commande/fiche.php
index a7d04670961..816df65ea85 100644
--- a/htdocs/commande/fiche.php
+++ b/htdocs/commande/fiche.php
@@ -2158,7 +2158,7 @@ else
// Convert date into timestamp format
if (in_array($extrafields->attribute_type[$key],array('date','datetime')))
{
- $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$object->array_options['options_'.$key];
+ $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$db->jdate($object->array_options['options_'.$key]);
}
if ($action == 'edit_extras' && $user->rights->commande->creer)
diff --git a/htdocs/compta/facture.php b/htdocs/compta/facture.php
index 1d6909874b1..82205be3e7b 100644
--- a/htdocs/compta/facture.php
+++ b/htdocs/compta/facture.php
@@ -3304,7 +3304,7 @@ else if ($id > 0 || ! empty($ref))
// Convert date into timestamp format
if (in_array($extrafields->attribute_type[$key],array('date','datetime')))
{
- $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$object->array_options['options_'.$key];
+ $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$db->jdate($object->array_options['options_'.$key]);
}
if ($action == 'edit_extras' && $user->rights->facture->creer)
diff --git a/htdocs/compta/prelevement/class/rejetprelevement.class.php b/htdocs/compta/prelevement/class/rejetprelevement.class.php
index dae4434639d..77bafae3603 100644
--- a/htdocs/compta/prelevement/class/rejetprelevement.class.php
+++ b/htdocs/compta/prelevement/class/rejetprelevement.class.php
@@ -50,7 +50,7 @@ class RejetPrelevement
$this->motifs = array();
$this->facturer = array();
- $this->motifs[0] = "";//$langs->trans("StatusMotif0");
+ $this->motifs[0] = ""; //$langs->trans("StatusMotif0");
$this->motifs[1] = $langs->trans("StatusMotif1");
$this->motifs[2] = $langs->trans("StatusMotif2");
$this->motifs[3] = $langs->trans("StatusMotif3");
@@ -174,7 +174,7 @@ class RejetPrelevement
//Tag invoice as unpaid
dol_syslog("RejetPrelevement::Create set_unpaid fac ".$fac->ref);
$fac->set_unpaid($fac->id, $user);
-
+
//TODO: Must be managed by notifications module
// Send email to sender of the standing order request
$this->_send_email($fac);
diff --git a/htdocs/compta/prelevement/ligne.php b/htdocs/compta/prelevement/ligne.php
index d94d9c4bfd2..28358dc75f5 100644
--- a/htdocs/compta/prelevement/ligne.php
+++ b/htdocs/compta/prelevement/ligne.php
@@ -63,35 +63,35 @@ if ($action == 'confirm_rejet')
$error++;
setEventMessage($langs->trans("ErrorFieldRequired",$langs->trans("Date")),'errors');
}
-
+
elseif ($daterej > dol_now())
{
$error++;
$langs->load("error");
setEventMessage($langs->transnoentities("ErrorDateMustBeBeforeToday"),'errors');
}
-
+
if (GETPOST('motif','alpha') == 0)
{
$error++;
setEventMessage($langs->trans("ErrorFieldRequired",$langs->transnoentities("RefusedReason")),'errors');
}
-
+
if ( ! $error )
{
$lipre = new LignePrelevement($db, $user);
-
+
if ($lipre->fetch($id) == 0)
-
+
{
$rej = new RejetPrelevement($db, $user);
-
+
$rej->create($user, $id, GETPOST('motif','alpha'), $daterej, $lipre->bon_rowid, GETPOST('facturer','int'));
header("Location: ligne.php?id=".$id);
exit;
}
-
+
}
else
{
diff --git a/htdocs/contact/class/contact.class.php b/htdocs/contact/class/contact.class.php
index e956f40a3e3..fb1ce97fd01 100644
--- a/htdocs/contact/class/contact.class.php
+++ b/htdocs/contact/class/contact.class.php
@@ -874,9 +874,9 @@ class Contact extends CommonObject
}
/**
- * Return label of a civility contact
+ * Return civility label of contact
*
- * @return string Translated name of civility
+ * @return string Translated name of civility
*/
function getCivilityLabel()
{
@@ -884,7 +884,7 @@ class Contact extends CommonObject
$langs->load("dict");
$code=$this->civilite_id;
- return $langs->trans("Civility".$code)!="Civility".$code ? $langs->trans("Civility".$code) : '';
+ return $langs->getLabelFromKey($this->db, "Civility".$code, "c_civilite", "code", "civilite", $code);
}
/**
diff --git a/htdocs/core/class/extrafields.class.php b/htdocs/core/class/extrafields.class.php
index 17226e7d461..6c6a9de1e99 100755
--- a/htdocs/core/class/extrafields.class.php
+++ b/htdocs/core/class/extrafields.class.php
@@ -825,7 +825,7 @@ class ExtraFields
$sql = 'SELECT '.$InfoFieldList[1];
$sql.= ' FROM '.MAIN_DB_PREFIX .$InfoFieldList[0];
- $sql.= ' WHERE '.$keyList.'="'.$this->db->escape($value).'"';
+ $sql.= ' WHERE '.$keyList.'=\''.$this->db->escape($value).'\'';
//$sql.= ' AND entity = '.$conf->entity;
dol_syslog(get_class($this).':showOutputField:$type=sellist sql='.$sql);
$resql = $this->db->query($sql);
diff --git a/htdocs/core/class/translate.class.php b/htdocs/core/class/translate.class.php
index 433100c4cb4..35271325247 100644
--- a/htdocs/core/class/translate.class.php
+++ b/htdocs/core/class/translate.class.php
@@ -643,13 +643,15 @@ class Translate
* Store key-label found into cache variable $this->cache_labels to save SQL requests to get labels.
*
* @param DoliBD $db Database handler
- * @param string $key Key to get label (key in language file)
+ * @param string $key Translation key to get label (key in language file)
* @param string $tablename Table name without prefix
* @param string $fieldkey Field for key
* @param string $fieldlabel Field for label
+ * @param string $keyforselect Use another value than the translation key for the where into select
* @return string Label in UTF8 (but without entities)
+ * @see dol_getIdFromCode
*/
- function getLabelFromKey($db,$key,$tablename,$fieldkey,$fieldlabel)
+ function getLabelFromKey($db,$key,$tablename,$fieldkey,$fieldlabel,$keyforselect='')
{
// If key empty
if ($key == '') return '';
@@ -670,7 +672,7 @@ class Translate
$sql = "SELECT ".$fieldlabel." as label";
$sql.= " FROM ".MAIN_DB_PREFIX.$tablename;
- $sql.= " WHERE ".$fieldkey." = '".$key."'";
+ $sql.= " WHERE ".$fieldkey." = '".($keyforselect?$keyforselect:$key)."'";
dol_syslog(get_class($this).'::getLabelFromKey sql='.$sql,LOG_DEBUG);
$resql = $db->query($sql);
if ($resql)
diff --git a/htdocs/core/lib/functions.lib.php b/htdocs/core/lib/functions.lib.php
index 2fc96042895..c440b8d33dd 100644
--- a/htdocs/core/lib/functions.lib.php
+++ b/htdocs/core/lib/functions.lib.php
@@ -4071,6 +4071,7 @@ function dol_osencode($str)
* @param string $fieldkey Field for code
* @param string $fieldid Field for id
* @return int Id of code
+ * @see getLabelFromKey
*/
function dol_getIdFromCode($db,$key,$tablename,$fieldkey='code',$fieldid='id')
{
diff --git a/htdocs/core/tpl/login.tpl.php b/htdocs/core/tpl/login.tpl.php
index 90caed4b8b4..bef263763de 100644
--- a/htdocs/core/tpl/login.tpl.php
+++ b/htdocs/core/tpl/login.tpl.php
@@ -134,7 +134,7 @@ if ($forgetpasslink || $helpcenterlink)
echo ' ';
echo '';
if ($forgetpasslink) {
- echo ' (';
+ echo '(';
echo $langs->trans('PasswordForgotten');
if (! $helpcenterlink) {
echo ')';
@@ -145,7 +145,7 @@ if ($forgetpasslink || $helpcenterlink)
if ($helpcenterlink) {
$url=DOL_URL_ROOT.'/support/index.php'.$moreparam;
if (! empty($conf->global->MAIN_HELPCENTER_LINKTOUSE)) $url=$conf->global->MAIN_HELPCENTER_LINKTOUSE;
- echo '';
+ echo '';
if ($forgetpasslink) {
echo ' - ';
} else {
diff --git a/htdocs/fichinter/class/fichinter.class.php b/htdocs/fichinter/class/fichinter.class.php
index b2c4884cf3e..a748ef0f549 100644
--- a/htdocs/fichinter/class/fichinter.class.php
+++ b/htdocs/fichinter/class/fichinter.class.php
@@ -372,7 +372,7 @@ class Fichinter extends CommonObject
// Define new ref
if (! $error && (preg_match('/^[\(]?PROV/i', $this->ref)))
{
- $num = $this->getNextNumRef($soc);
+ $num = $this->getNextNumRef($this->thirdparty);
}
else
{
diff --git a/htdocs/holiday/fiche.php b/htdocs/holiday/fiche.php
index db27fb1116a..48d5f591edd 100644
--- a/htdocs/holiday/fiche.php
+++ b/htdocs/holiday/fiche.php
@@ -854,8 +854,8 @@ else
// Si refus de la demande
if ($action == 'refuse' && $cp->statut == 2 && $user->id == $cp->fk_validator)
{
- $array_input = array(array('type'=>"text",'label'=>"Entrez ci-dessous un motif de refus :",'name'=>"detail_refuse",'size'=>"50",'value'=>""));
- $ret=$form->form_confirm("fiche.php?id=".$id."&action=confirm_refuse", $langs->trans("TitleRefuseCP"), "", "confirm_refuse", $array_input, 1, 0);
+ $array_input = array(array('type'=>"text",'label'=> $langs->trans('DetailRefusCP'),'name'=>"detail_refuse",'size'=>"50",'value'=>""));
+ $ret=$form->form_confirm("fiche.php?id=".$id."&action=confirm_refuse", $langs->trans("TitleRefuseCP"), $langs->trans('ConfirmRefuseCP'), "confirm_refuse", $array_input, 1, 0);
if ($ret == 'html') print ' ';
}
diff --git a/htdocs/langs/ca_ES/margins.lang b/htdocs/langs/ca_ES/margins.lang
index 8a0763f5214..7f80518f2ff 100644
--- a/htdocs/langs/ca_ES/margins.lang
+++ b/htdocs/langs/ca_ES/margins.lang
@@ -1,8 +1,6 @@
# Dolibarr language file - ca_ES - margins
CHARSET=UTF-8
-Module59000Name=Marges
-Module59000Desc=Gestió de marges comercials
Margin=Marge
Margins=Marges
TotalMargin=Marge total
diff --git a/htdocs/langs/el_GR/admin.lang b/htdocs/langs/el_GR/admin.lang
index 5606120714b..c52e1530095 100644
--- a/htdocs/langs/el_GR/admin.lang
+++ b/htdocs/langs/el_GR/admin.lang
@@ -74,10 +74,6 @@ OSTZ=Ζώνη Ώρας OS server
PHPTZ=Ζώνη Ώρας PHP server
PHPServerOffsetWithGreenwich=PHP server offset width Greenwich (seconds)
ClientOffsetWithGreenwich=Client/Browser offset width Greenwich (seconds)
-CurrentHour=PHP server hour
-CompanyTZ= Time Zone company (main company)
-CompanyHour= Hour company (main company)
-CurrentSessionTimeOut=Current session timeout
OSEnv=Περιβάλλον OS
Box=Πλαίσιο
Boxes=Πλαίσια
diff --git a/htdocs/langs/en_US/admin.lang b/htdocs/langs/en_US/admin.lang
index 6027ddaa279..71dfebd5af5 100644
--- a/htdocs/langs/en_US/admin.lang
+++ b/htdocs/langs/en_US/admin.lang
@@ -117,7 +117,7 @@ ClientOffsetWithGreenwich=Client/Browser offset width Greenwich (seconds)
DaylingSavingTime=Daylight saving time
CurrentHour=PHP Time (server)
CompanyTZ=Company Time Zone (main company)
-CompanyHour=Company Time(main company)
+CompanyHour=Company Time (main company)
CurrentSessionTimeOut=Current session timeout
OSEnv=OS Environment
Box=Box
diff --git a/htdocs/langs/en_US/companies.lang b/htdocs/langs/en_US/companies.lang
index 56238311a27..9506f72abc5 100644
--- a/htdocs/langs/en_US/companies.lang
+++ b/htdocs/langs/en_US/companies.lang
@@ -377,7 +377,7 @@ SupplierCategory=Supplier category
JuridicalStatus200=Independant
DeleteFile=Delete file
ConfirmDeleteFile=Are you sure you want to delete this file?
-AllocateCommercial=Allocate a commercial
+AllocateCommercial=Assigned to sale representative
SelectCountry=Select a country
SelectCompany=Select a third party
Organization=Organization
diff --git a/htdocs/langs/en_US/margins.lang b/htdocs/langs/en_US/margins.lang
index f4975b719c7..e8c5ab38b6b 100644
--- a/htdocs/langs/en_US/margins.lang
+++ b/htdocs/langs/en_US/margins.lang
@@ -1,8 +1,6 @@
# Dolibarr language file - en_US - marges
CHARSET=UTF-8
-Module59000Name=Margins
-Module59000Desc=Profit margins management
Margin=Margin
Margins=Margins
TotalMargin=Total Margin
diff --git a/htdocs/langs/es_ES/margins.lang b/htdocs/langs/es_ES/margins.lang
index b4614596ae6..11505132287 100644
--- a/htdocs/langs/es_ES/margins.lang
+++ b/htdocs/langs/es_ES/margins.lang
@@ -1,8 +1,6 @@
# Dolibarr language file - es_ES - margins
CHARSET=UTF-8
-Module59000Name=Márgenes
-Module59000Desc=Gestión de márgenes comerciales
Margin=Margen
Margins=Márgenes
TotalMargin=Margen total
diff --git a/htdocs/langs/fr_FR/margins.lang b/htdocs/langs/fr_FR/margins.lang
index b30e79a3e7b..19910d90291 100644
--- a/htdocs/langs/fr_FR/margins.lang
+++ b/htdocs/langs/fr_FR/margins.lang
@@ -1,8 +1,6 @@
# Dolibarr language file - fr_FR - margins
CHARSET=UTF-8
-Module59000Name=Marges
-Module59000Desc=Gestion des marges commerciales
Margin=Marge
Margins=Marges
TotalMargin=Marge totale
diff --git a/htdocs/langs/nb_NO/companies.lang b/htdocs/langs/nb_NO/companies.lang
index 287d2e2c08e..3b1531f5391 100644
--- a/htdocs/langs/nb_NO/companies.lang
+++ b/htdocs/langs/nb_NO/companies.lang
@@ -248,7 +248,6 @@ NoOtherDeliveryAddress=Ingen alternativ leveringsadresse lagt inn
JuridicalStatus200=Uavhengig
DeleteFile=Slett fil
ConfirmDeleteFile=Er du sikker på at du vil slette denne filen?
-AllocateCommercial=Allocate a commercial
SelectCountry=Velg land
SelectCompany=Velg tredjepart
Organization=Organisasjon
diff --git a/htdocs/langs/nl_NL/dict.lang b/htdocs/langs/nl_NL/dict.lang
index c430b86e6d0..37aa3207418 100644
--- a/htdocs/langs/nl_NL/dict.lang
+++ b/htdocs/langs/nl_NL/dict.lang
@@ -247,10 +247,11 @@ CountryME = Montenegro
CountryBL = Saint Barthelemy
CountryMF = Saint Martin
##### Civilities ##### =
-CivilityMME = Mej.
-CivilityMR = Dhr.
-CivilityMLE = Mevr.
+CivilityMME = Mevrouw
+CivilityMR = Meneer
+CivilityMLE = Mejuffrouw
CivilityMTRE = Meester
+CivilityDR = Dokter
##### Currencies ##### =
Currencyeuros = Euro
CurrencyAUD = Australische Dollars
@@ -289,17 +290,17 @@ CurrencyXOF = Francs CFA BCEAO
CurrencySingXOF = Franc CFA BCEAO
CurrencyXPF = Francs CFP
CurrencySingXPF = Franc CFP
-
-
-// START - Lines generated via autotranslator.php tool (2011-10-10 01:37:25).
-// Reference language: en_US -> nl_NL
-CurrencyUAH=Hryvnia
-CurrencySingUAH=Hryvnia
-DemandReasonTypeSRC_INTE=Internet
-DemandReasonTypeSRC_CAMP_MAIL=Mailing campagne
-DemandReasonTypeSRC_CAMP_EMAIL=E-mailen campagne
-DemandReasonTypeSRC_CAMP_PHO=Telefoon campagne
-DemandReasonTypeSRC_CAMP_FAX=Fax-campagne
-DemandReasonTypeSRC_COMM=Commercieel contact
-DemandReasonTypeSRC_SHOP=Winkel contact
-// STOP - Lines generated via autotranslator.php tool (2011-10-10 01:39:55).
+
+
+// START - Lines generated via autotranslator.php tool (2011-10-10 01:37:25).
+// Reference language: en_US -> nl_NL
+CurrencyUAH=Hryvnia
+CurrencySingUAH=Hryvnia
+DemandReasonTypeSRC_INTE=Internet
+DemandReasonTypeSRC_CAMP_MAIL=Mailing campagne
+DemandReasonTypeSRC_CAMP_EMAIL=E-mailen campagne
+DemandReasonTypeSRC_CAMP_PHO=Telefoon campagne
+DemandReasonTypeSRC_CAMP_FAX=Fax-campagne
+DemandReasonTypeSRC_COMM=Commercieel contact
+DemandReasonTypeSRC_SHOP=Winkel contact
+// STOP - Lines generated via autotranslator.php tool (2011-10-10 01:39:55).
\ No newline at end of file
diff --git a/htdocs/langs/tr_TR/margins.lang b/htdocs/langs/tr_TR/margins.lang
index f8d8d6a39a9..c4e807cf8e7 100644
--- a/htdocs/langs/tr_TR/margins.lang
+++ b/htdocs/langs/tr_TR/margins.lang
@@ -1,8 +1,6 @@
# Dolibarr language file - en_US - marges
CHARSET=UTF-8
-Module59000Name=Oranlar
-Module59000Desc=Kar oranı yönetimi
Margin=Oran
Margins=Oranlar
TotalMargin=Toplam Oran
diff --git a/htdocs/societe/note.php b/htdocs/societe/note.php
index 8fbd6c6187f..372177c0c89 100644
--- a/htdocs/societe/note.php
+++ b/htdocs/societe/note.php
@@ -25,10 +25,6 @@
* \ingroup societe
*/
-error_reporting(E_ALL);
-ini_set('display_errors', true);
-ini_set('html_errors', false);
-
require '../main.inc.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';
diff --git a/htdocs/theme/amarok/style.css.php b/htdocs/theme/amarok/style.css.php
index 5788b0f011f..4f55463a323 100755
--- a/htdocs/theme/amarok/style.css.php
+++ b/htdocs/theme/amarok/style.css.php
@@ -557,6 +557,15 @@ img.login, img.printer, img.entity {
font-weight:bold;
}
+.alogin {
+ color: #FFF;
+ font-weight: normal;
+}
+.alogin:hover {
+ color: #FFF;
+ text-decoration:underline;
+}
+
div.login_main_home {
color: #000000;
}
diff --git a/htdocs/theme/auguria/style.css.php b/htdocs/theme/auguria/style.css.php
index f998fdc4e9c..41bdadf037c 100644
--- a/htdocs/theme/auguria/style.css.php
+++ b/htdocs/theme/auguria/style.css.php
@@ -596,6 +596,15 @@ div.login a:hover {
text-decoration:underline;
}
+.alogin, .alogin:hover {
+ color: #888 !important;
+ font-weight: normal !important;
+ font-size: px !important;
+}
+.alogin:hover {
+ text-decoration:underline !important;
+}
+
img.login, img.printer, img.entity {
padding: dol_optimize_smallscreen?'0':'8')?>px 0px 0px 0px;
margin: 0px 0px 0px 8px;
diff --git a/htdocs/theme/bureau2crea/style.css.php b/htdocs/theme/bureau2crea/style.css.php
index f87364fef9b..46abe55ecae 100644
--- a/htdocs/theme/bureau2crea/style.css.php
+++ b/htdocs/theme/bureau2crea/style.css.php
@@ -640,6 +640,15 @@ div.login a:hover {
text-decoration:underline;
}
+.alogin, .alogin:hover {
+ color: #888 !important;
+ font-weight: normal !important;
+ font-size: px !important;
+}
+.alogin:hover {
+ text-decoration:underline !important;
+}
+
img.login, img.printer, img.entity {
padding: dol_optimize_smallscreen?'0':'8')?>px 0px 0px 0px;
margin: 0px 0px 0px 8px;
diff --git a/htdocs/theme/cameleo/style.css.php b/htdocs/theme/cameleo/style.css.php
index 568e81f13f2..be7c6532f44 100644
--- a/htdocs/theme/cameleo/style.css.php
+++ b/htdocs/theme/cameleo/style.css.php
@@ -651,6 +651,15 @@ div.login a:hover {
text-decoration:underline;
}
+.alogin, .alogin:hover {
+ color: #888 !important;
+ font-weight: normal !important;
+ font-size: px !important;
+}
+.alogin:hover {
+ text-decoration:underline !important;
+}
+
img.login, img.printer, img.entity {
padding: dol_optimize_smallscreen?'0':'8')?>px 0px 0px 0px;
margin: 0px 0px 0px 8px;
diff --git a/htdocs/theme/eldy/style.css.php b/htdocs/theme/eldy/style.css.php
index 1fbca3e51a0..02e871c20f6 100644
--- a/htdocs/theme/eldy/style.css.php
+++ b/htdocs/theme/eldy/style.css.php
@@ -854,7 +854,14 @@ div.login a:hover {
color: #;
text-decoration:underline;
}
-
+.alogin, .alogin:hover {
+ color: #888 !important;
+ font-weight: normal !important;
+ font-size: px !important;
+}
+.alogin:hover {
+ text-decoration:underline !important;
+}
img.login, img.printer, img.entity {
padding: dol_optimize_smallscreen?'0':'8')?>px 0px 0px 0px;
margin: 0px 0px 0px 8px;
@@ -870,6 +877,8 @@ img.login, img.printer, img.entity {
div.vmenu, td.vmenu {
margin-: 2px;
+ position: relative;
+ float: left;
padding: 0px;
padding-bottom: 0px;
padding-top: 1px;
|
diff --git a/htdocs/core/class/commonobject.class.php b/htdocs/core/class/commonobject.class.php
index b5dee2a3c76..e283c977f5f 100644
--- a/htdocs/core/class/commonobject.class.php
+++ b/htdocs/core/class/commonobject.class.php
@@ -44,6 +44,9 @@ abstract class CommonObject
public $civility_id;
public $array_options=array();
+
+ public $linkedObjectsIds;
+ public $linkedObjects;
// No constructor as it is an abstract class
@@ -1649,7 +1652,7 @@ abstract class CommonObject
}
/**
* Fetch array of objects linked to current object. Links are loaded into this->linked_object array.
*
* @param int $sourceid Object source id
* @param string $sourcetype Object source type
@@ -1708,6 +1711,7 @@ abstract class CommonObject
$sql.= "(fk_source = '".$sourceid."' AND sourcetype = '".$sourcetype."')";
$sql.= " ".$clause." (fk_target = '".$targetid."' AND targettype = '".$targettype."')";
}
+ $sql .= ' ORDER BY sourcetype';
//print $sql;
dol_syslog(get_class($this)."::fetchObjectLink sql=".$sql);
@@ -2236,7 +2240,7 @@ abstract class CommonObject
// Convert date into timestamp format
if (in_array($extrafields->attribute_type[$key],array('date','datetime')))
{
- $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$this->array_options['options_'.$key];
+ $value = isset($_POST["options_".$key])?dol_mktime($_POST["options_".$key."hour"], $_POST["options_".$key."min"], 0, $_POST["options_".$key."month"], $_POST["options_".$key."day"], $_POST["options_".$key."year"]):$this->db->jdate($this->array_options['options_'.$key]);
}
$out .= '
'.$label.' | ';
@@ -1649,7 +1652,7 @@ abstract class CommonObject
}
/**
- * Fetch array of objects linked to current object. Links are loaded into this->linked_object array.
+ * Fetch array of objects linked to current object. Links are loaded into this->linkedObjects array.
*
* @param int $sourceid Object source id
$out .='';